@@ -104,7 +104,9 @@ class Plant:
         self.input_dim = 0
         self.muscle_name = []
         self.muscle_state_dim = self.muscle.state_dim
-        self.geometry_state_dim = 2 + self.skeleton.dof  # musculotendon length & velocity + as many moments as dofs
+        self.geometry_state_dim = 2 + self.dof  # musculotendon length & velocity + as many moments as dofs
+        self.geometry_state_name =\
+            ['musculotendon length', 'musculotendon velocity'] + ['moment for joint ' + str(d) for d in range(self.dof)]
         self.tobuild__muscle = self.muscle.to_build_dict
         self.tobuild__default = self.muscle.to_build_dict_default
 
@@ -244,8 +246,9 @@ class Plant:
                 "coordinates": [self._path_coordinates.squeeze()[:, k].tolist() for k in ix],
             }
 
-            for param, value in self.tobuild__muscle.items():
-                d[param] = value[m]
+            if not self._muscle_config_is_empty:
+                for param, value in self.tobuild__muscle.items():
+                    d[param] = value[m]
 
             cfg[self.muscle_name[m]] = d
         if not cfg:
@@ -486,6 +489,12 @@ class Plant:
 
     def get_geometry(self, joint_state):
         """Computes the geometry state from the joint state.
+        Computes the geometry state from the joint state.
+        Geometry state dimensionality is `[n_batch, n_timesteps, n_states, n_muscles]`. By default, there are as many
+        states as there are moments (that is, one per degree of freedom in the plant) plus two for musculotendon length
+        and musculotendon velocity. However, note that how many states and what they represent may vary depending on
+        the :class:`Plant` subclass. This should be available via the
+        :attr:`geometry_state_names` attribute.
 
         Args:
             joint_state: `Tensor`, the joint state from which the geometry state is computed.
@@ -587,7 +596,7 @@ class RigidTendonArm26(Plant):
     polynomial functions. The default integration method is Euler.
 
     If no `skeleton` input is provided, this object will use a :class:`motornet.plants.skeletons.TwoDofArm` skeleton,
-    with the following parameters:
+    with the following parameters (from `[1]`):
 
     - `m1 = 1.82`
     - `m2 = 1.43`
@@ -599,14 +608,14 @@ class RigidTendonArm26(Plant):
     - `l2 = 0.333`
 
     The default shoulder and elbow lower limits are defined as `0`, and their default upper limits as `135` and `155`
-    degrees, respectively. These parameters come from `[1]`.
+    degrees, respectively.
 
     The `kwargs` inputs are passed as-is to the parent :class:`Plant` class.
 
     References:
-        [1] `Kistemaker DA, Wong JD, Gribble PL. The central nervous system does not minimize energy cost in arm
-        movements. J Neurophysiol. 2010 Dec;104(6):2985-94. doi: 10.1152/jn.00483.2010. Epub 2010 Sep 8. PMID:
-        20884757.`
+        [1] `Nijhof, E.-J., & Kouwenhoven, E. Simulation of Multijoint Arm Movements (2000). In J. M. Winters & P. E.
+        Crago, Biomechanics and Neural Control of Posture and Movement (pp. 363–372). Springer New York.
+        doi: 10.1007/978-1-4612-2104-3_29`
 
     Args:
         muscle_type: A :class:`motornet.plants.muscles.Muscle` object class or subclass. This defines the type of muscle
